@@ -183,7 +183,12 @@ void KgpgEditor::initActions()
 
 bool KgpgEditor::queryClose()
 {
-    return saveBeforeClear();
+	bool b = saveBeforeClear();
+	if (b) {
+		view->editor->clear();
+		newText();
+	}
+	return b;
 }
 
 bool KgpgEditor::saveBeforeClear()
@@ -650,7 +655,7 @@ void KgpgEditor::slotCheckMd5()
 
 void KgpgEditor::importSignatureKey(const QString &id)
 {
-    KeyServer *kser = new KeyServer(0, false);
+    KeyServer *kser = new KeyServer(0, m_model);
     kser->slotSetText(id);
     kser->slotImport();
 }
