@@ -19,19 +19,21 @@
 #define KEYSMANAGER_H
 
 #include <QClipboard>
+#include <QSet>
 
 #include <KToggleAction>
 #include <KXmlGuiWindow>
 #include <KDialog>
 #include <KUrl>
 
+#include <solid/networking.h>
+
 #include "kgpgkey.h"
 #include "ui_adduid.h"
 #include "kgpginterface.h"
 #include "kgpgitemmodel.h"
 #include "kgpgitemnode.h"
 
-class QCloseEvent;
 class QEvent;
 
 class KSelectAction;
@@ -39,14 +41,25 @@ class KPassivePopup;
 class KStatusBar;
 class KMenu;
 class KLineEdit;
+class KAction;
 
 class KgpgInterface;
 class KeyServer;
 class KgpgEditor;
 class KeyServer;
-class KGpgTransaction;
 class KeyListProxyModel;
 class KeyTreeView;
+class KGpgDelUid;
+class KGpgAddPhoto;
+class KGpgAddUid;
+class KGpgGenerateKey;
+class KGpgDelKey;
+class KGpgImport;
+class KGpgTextInterface;
+
+namespace Experimental {
+	class KNotificationItem;
+}
 
 class AddUid : public QWidget, public Ui::AddUid
 {
@@ -64,6 +77,14 @@ public:
     KeysManager(QWidget *parent = 0);
     ~KeysManager();
 
+    KGpgItemModel *getModel();
+
+    KgpgEditor *s_kgpgEditor;
+
+    void saveToggleOpts(void);
+    void showTrayMessage(const QString &message);
+
+private:
     KToggleAction *sTrust;
     KToggleAction *sCreat;
     KToggleAction *sExpi;
@@ -72,9 +93,7 @@ public:
     KToggleAction *longId;
     KSelectAction *photoProps;
     KSelectAction *trustProps;
-    KgpgEditor *s_kgpgEditor;
 
-    void saveToggleOpts(void);
 signals:
     void readAgainOptions();
     void certificate(QString);
@@ -93,45 +112,58 @@ public slots:
     void slotSetDefaultKey(const QString &newID);
     void showKeyManager();
     bool importRemoteKey(const QString &keyIDs);
+    bool importRemoteKeys(const QStringList &keyIDs, const bool dialog = true);
     void showKeyServer();
     void showOptions();
     void slotOpenEditor();
-
+    void slotImport(const QString &text);
+    void slotImport(const KUrl::List &files);
+    /**
+     * When you click on "encrypt the clipboard" in the systray,
+     * this slot will open the dialog to choose a key and encrypt the
+     * clipboard.
+     */
+    void clipEncrypt();
+    void clipDecrypt();
+    void clipSign();
+    
 protected:
-    void closeEvent(QCloseEvent *e);
     bool eventFilter(QObject *, QEvent *e);
+    void removeFromGroups(KGpgKeyNode *nd);
 
 private slots:
     void statusBarTimeout();
     void changeMessage(const QString &msg, const int nb, const bool keep = false);
 
-    void slotGenerateKeyProcess(KgpgInterface *);
-    void slotGenerateKeyDone(int res, KgpgInterface *interface, const QString &name, const QString &email, const QString &fingerprint);
+    void slotGenerateKeyProcess();
+    void slotGenerateKeyDone(int res);
 
     void slotShowTrust();
     void slotShowSize();
     void slotShowCreation();
     void slotShowExpiration();
 
-    void slotAddUidFin(int res, KgpgInterface *interface);
-    void slotDelPhotoFinished(int res, KgpgInterface *interface);
+    void slotAddUidFin(int res);
+    void slotDelPhotoFinished(int res);
     void quitApp();
     void slotToggleSecret(bool);
     void slotShowLongId(bool);
     void slotSetTrustFilter(int);
     void slotGotoDefaultKey();
     void slotDelUid();
+    void slotDelUidDone(int);
     void slotPrimUid();
     void slotAddUid();
     void slotAddUidEnable(const QString &name);
     void slotUpdatePhoto();
     void slotDeletePhoto();
     void slotAddPhoto();
+    void slotAddPhotoFinished(int res);
     void slotSetPhotoSize(int size);
     void slotShowPhoto();
-    void slotrevoke(const QString &keyID, const QString &revokeUrl, const int reason, const QString &description);
+    void slotrevoke(const QString &keyID, const KUrl &revokeUrl, const int reason, const QString &description);
     void revokeWidget();
-    void doFilePrint(const QString &url);
+    void doFilePrint(const KUrl &url);
     void doPrint(const QString &txt);
     void checkList();
     void signLoop();
@@ -147,9 +179,7 @@ private slots:
     void signuid();
     void delsignkey();
     void preimportsignkey();
-    void importsignkey(const QStringList &importKeyId);
     void importallsignkey();
-    void importfinished();
     void signatureResult(int success, const QString &keyId, KgpgInterface*);
     void delsignatureResult(bool);
     void defaultAction(const QModelIndex &);
@@ -168,20 +198,35 @@ private slots:
     void editGroup();
     void createNewGroup();
     void deleteGroup();
-    void slotImportRevoke(const QString &url);
+    void slotImportRevoke(const KUrl &url);
     void slotImportRevokeTxt(const QString &revokeText);
     void refreshKeyFromServer();
+    void slotKeyRefreshDone(int result);
     void slotregenerate();
     void secretKeyDeleted(int);
-    void getMissingSigs(QStringList *missingKeys, KGpgExpandableNode *nd);
+    void getMissingSigs(QSet<QString> &missingKeys, const KGpgExpandableNode *nd);
     void slotEditDone(int exitcode);
-    void importRemoteFinished(KGpgTransaction *);
+    void importRemoteFinished(int result);
+    void slotRefreshKeys(KgpgInterface *iface, const QStringList &keys);
+    void slotDelKeyDone(int ret);
+    void slotImportDone(int ret);
+    void slotImportDone(KGpgImport *import, int ret);
+    void slotSetClip(const QString &newtxt, KGpgTextInterface *iface);
+
+    void slotNetworkUp();
+    void slotNetworkDown();
 
 private:
     KGpgItemModel *imodel;
     KeyListProxyModel *iproxy;
     KeyTreeView *iview;
 
+    KGpgDelUid *m_deluid;
+    KGpgAddPhoto *m_addphoto;
+    KGpgAddUid *m_adduid;
+    KGpgGenerateKey *m_genkey;
+    KGpgDelKey *m_delkey;
+
     QString globalkeyID;
     QString searchString;
 
@@ -206,19 +251,22 @@ private:
     KLineEdit *m_listviewsearch;
     KDialog *addUidWidget;
 
-    QAction *importSignatureKey;
-    QAction *importAllSignKeys;
-    QAction *signKey;
-    QAction *signUid;
-    QAction *refreshKey;
-    QAction *editKey;
-    QAction *setPrimUid;
-    QAction *delUid;
-    QAction *delSignKey;
-    QAction *deleteKey;
-    QAction *editCurrentGroup;
-    QAction *delGroup;
-    QAction *setDefaultKey;
+    KAction *importSignatureKey;
+    KAction *importAllSignKeys;
+    KAction *signKey;
+    KAction *signUid;
+    KAction *refreshKey;
+    KAction *editKey;
+    KAction *setPrimUid;
+    KAction *delUid;
+    KAction *delSignKey;
+    KAction *deleteKey;
+    KAction *editCurrentGroup;
+    KAction *delGroup;
+    KAction *setDefaultKey;
+    KAction *kserver;
+    KAction *openEditor;
+    KAction *goToDefaultKey;
 
     KeyServer *kServer;
     KgpgInterface *revKeyProcess;
@@ -236,28 +284,17 @@ private:
 
     KGpgKeyNode *terminalkey; // the key currently edited in a terminal
     KGpgKeyNode *delkey;	// key currently deleted
-};
+    KGpgKeyNodeList m_delkeys;
 
-class KGpgTransaction : public QObject
-{
+    void startImport(KGpgImport *import);
 
-	Q_OBJECT
+    // react to network status changes
+    bool m_online;
+    Solid::Networking::Notifier *m_netnote;
+    void toggleNetworkActions(bool online);
 
-public:
-	KgpgInterface *iface;
-
-	explicit KGpgTransaction();
-
-	~KGpgTransaction()
-	{
-		delete iface;
-	}
-
-private slots:
-	void slotDownloadKeysFinished(QList<int>, QStringList, bool, QString, KgpgInterface*);
-
-signals:
-	void receiveComplete(KGpgTransaction *);
+    Experimental::KNotificationItem *m_trayicon;
+    void setupTrayIcon();
 };
 
 #endif // KEYSMANAGER_H
