@@ -1,5 +1,5 @@
-/*
- * Copyright (C) 2008 Rolf Eike Beer <kde@opensource.sf-tec.de>
+/**
+ * Copyright (C) 2008,2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -31,6 +31,9 @@ public:
 protected:
 	virtual bool nextLine(const QString &line);
 	virtual bool preStart();
+
+private:
+	bool m_seenold;		///< old password correctly entered
 };
 
 #endif // KGPGCHANGEPASS_H
