@@ -659,6 +659,23 @@ void ByteArrayColumnViewPrivate::pauseCursor()
     updateCursor( *mInactiveColumn );
 }
 
+
+QRect ByteArrayColumnViewPrivate::cursorRect() const
+{
+    Q_Q( const ByteArrayColumnView );
+
+    const int x = mActiveColumn->xOfLinePosition( mTableCursor->pos() ) - q->xOffset();
+    const int y = q->lineHeight() * mTableCursor->line() - q->yOffset();
+    const int w = mActiveColumn->byteWidth();
+    const int h = q->lineHeight();
+    const QPoint viewportPoint( x, y );
+    const QPoint point = q->viewport()->mapToParent( viewportPoint ); // TODO: seems still missing some offset
+    const QSize size( w, h );
+
+    const QRect result( point, size );
+    return result;
+}
+
 void ByteArrayColumnViewPrivate::updateCursor( const AbstractByteArrayColumnRenderer& column )
 {
     Q_Q( ByteArrayColumnView );
@@ -811,7 +828,7 @@ void ByteArrayColumnViewPrivate::updateChanged()
         column = mCharColumn;
     }
 
-    // any colums to paint?
+    // any columns to paint?
     if( dirtyColumns.size() > 0 )
     {
         // calculate affected lines/indizes
@@ -1119,6 +1136,7 @@ void ByteArrayColumnViewPrivate::mouseReleaseEvent( QMouseEvent* mouseEvent )
     if( !mOverWrite ) emit q->cutAvailable( mTableRanges->hasSelection() );
     emit q->copyAvailable( mTableRanges->hasSelection() );
     emit q->selectionChanged( mTableRanges->hasSelection() );
+    emit q->selectionChanged( mTableRanges->selection() );
 }
 
 
@@ -1223,6 +1241,8 @@ void ByteArrayColumnViewPrivate::handleMouseMove( const QPoint& point ) // handl
 
     unpauseCursor();
     emit q->cursorPositionChanged( cursorPosition() );
+    emit q->selectionChanged( mTableRanges->hasSelection() );
+    emit q->selectionChanged( mTableRanges->selection() );
 }
 
 
