@@ -630,6 +630,22 @@ void ByteArrayRowViewPrivate::pauseCursor()
     updateCursor( *mByteArrayColumn );
 }
 
+QRect ByteArrayRowViewPrivate::cursorRect() const
+{
+    Q_Q( const ByteArrayRowView );
+
+    const int x = mByteArrayColumn->xOfLinePosition( mTableCursor->pos() ) - q->xOffset();
+    const int y = q->lineHeight() * mTableCursor->line()
+                  + mByteArrayColumn->yOfCodingId( mActiveCoding ) - q->yOffset();
+    const int w = mByteArrayColumn->byteWidth();
+    const int h = q->lineHeight();
+    const QPoint viewportPoint( x, y );
+    const QPoint point = q->viewport()->mapToParent( viewportPoint ); // TODO: seems still missing some offset
+    const QSize size( w, h );
+
+    const QRect result( point, size );
+    return result;
+}
 
 // TODO: should be movable to base class
 void ByteArrayRowViewPrivate::updateCursor( const ByteArrayRowColumnRenderer& column )
@@ -777,7 +793,7 @@ void ByteArrayRowViewPrivate::updateChanged()
         mByteArrayColumn->prepareRendering( Xs );
     }
 
-    // any colums to paint?
+    // any columns to paint?
     if( dirtyColumns.size() > 0 )
     {
         // calculate affected lines/indizes
@@ -1085,6 +1101,7 @@ void ByteArrayRowViewPrivate::mouseReleaseEvent( QMouseEvent* mouseEvent )
     if( !mOverWrite ) emit q->cutAvailable( mTableRanges->hasSelection() );
     emit q->copyAvailable( mTableRanges->hasSelection() );
     emit q->selectionChanged( mTableRanges->hasSelection() );
+    emit q->selectionChanged( mTableRanges->selection() );
 }
 
 
@@ -1189,6 +1206,8 @@ void ByteArrayRowViewPrivate::handleMouseMove( const QPoint& point ) // handles
 
     unpauseCursor();
     emit q->cursorPositionChanged( cursorPosition() );
+    emit q->selectionChanged( mTableRanges->hasSelection() );
+    emit q->selectionChanged( mTableRanges->selection() );
 }
 
 
