@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta program, part of the KDE project.
 
-    Copyright 2006-2008 Friedrich W. H. Kossebau <kossebau@kde.org>
+    Copyright 2006-2009 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -30,7 +30,7 @@
 
 // Program
 static const char ProgramId[] =          "okteta";
-static const char ProgramVersion[] =     "0.2.1";
+static const char ProgramVersion[] =     "0.3.0";
 static const char ProgramHomepage[] =    "http://utils.kde.org/projects/okteta";
 // Author
 static const char FWHKEmailAddress[] =   "kossebau@kde.org";
@@ -39,15 +39,13 @@ static const char FWHKEmailAddress[] =   "kossebau@kde.org";
 OktetaAboutData::OktetaAboutData()
 : KAboutData( ProgramId, 0,
               ki18n("Okteta"), ProgramVersion, // name
-              ki18n("KDE bytes editor"), // description
+              ki18n("KDE byte editor"), // description
               KAboutData::License_GPL_V2,
-              ki18n("Copyright 2006-2008 Friedrich W. H. Kossebau"), //copyright
-              ki18n("Edit files as an array of bytes"), // comment
+              ki18n("Copyright 2006-2009 Friedrich W. H. Kossebau"), //copyright
+              ki18n("Edit the raw data of files"), // comment
               ProgramHomepage )
 {
-#if KDE_IS_VERSION(4,0,70)
     addLicense(KAboutData::License_GPL_V3);
-#endif
     setOrganizationDomain( "kde.org" );
     addAuthor( ki18n("Friedrich W. H. Kossebau"), // name
                ki18n("Author"), // task
