@@ -43,7 +43,10 @@ KAbstractFindDialog::KAbstractFindDialog( QWidget *parent )
 {
     setButtons( Ok | Cancel );
     setDefaultButton( Ok );
-    enableButtonOk( false );
+
+    // TODO: setting ok button to disabled as before done gets overwritten to true
+    // if setting the button gui with an inline KGuiItem in the subclass,
+    // which has no parameter for enabled and defaults to true
 }
 
 void KAbstractFindDialog::setupFindBox()
@@ -52,7 +55,6 @@ void KAbstractFindDialog::setupFindBox()
     setMainWidget( page );
 
     QVBoxLayout *pageLayout = new QVBoxLayout( page );
-    pageLayout->setSpacing( spacingHint() );
     pageLayout->setMargin( 0 );
 
     // find term
@@ -60,9 +62,8 @@ void KAbstractFindDialog::setupFindBox()
     pageLayout->addWidget( findBox );
 
     QVBoxLayout *findBoxLayout = new QVBoxLayout;
-    findBoxLayout->setSpacing( spacingHint() );
 
-    QLabel *bytesLabel = new QLabel( i18nc("@label:textbox","Byte String to F&ind:"), findBox );
+    QLabel *bytesLabel = new QLabel( i18nc("@label:textbox","Byte string to f&ind:"), findBox );
     SearchDataEdit = new KByteArrayLineEdit( findBox );
     connect( SearchDataEdit, SIGNAL(dataChanged(const QByteArray&)), SLOT(onSearchDataChanged(const QByteArray&)) );
     connect( SearchDataEdit, SIGNAL(formatChanged(int)), SLOT(onSearchDataFormatChanged(int)) );
@@ -96,7 +97,6 @@ void KAbstractFindDialog::setupCheckBoxes( QCheckBox *optionCheckBox )
     pageLayout->addWidget( optionsBox );
 
     QGridLayout *optionsBoxLayout = new QGridLayout( optionsBox );
-    optionsBoxLayout->setSpacing( spacingHint() );
 
     CaseSensitiveCheckBox = new QCheckBox( i18nc("@option:check","C&ase sensitive"),optionsBox);
     CaseSensitiveCheckBox->setWhatsThis( i18nc("@info:whatsthis","Perform a case sensitive search: "
@@ -131,8 +131,11 @@ void KAbstractFindDialog::setupCheckBoxes( QCheckBox *optionCheckBox )
 
 bool KAbstractFindDialog::fromCursor()            const { return AtCursorCheckBox->isChecked(); }
 bool KAbstractFindDialog::inSelection()           const { return SelectedCheckBox->isChecked(); }
-bool KAbstractFindDialog::ignoreCase()            const { return !CaseSensitiveCheckBox->isChecked(); }
 KFindDirection KAbstractFindDialog::direction() const { return BackwardsCheckBox->isChecked() ? FindBackward : FindForward; }
+bool KAbstractFindDialog::ignoreCase()            const
+{
+    return ( SearchDataEdit->format() == KByteArrayLineEdit::CharCoding ) && ! CaseSensitiveCheckBox->isChecked();
+}
 
 QByteArray KAbstractFindDialog::data()  const
 {
@@ -158,7 +161,7 @@ void KAbstractFindDialog::onSearchDataFormatChanged( int index )
 {
     const bool isCharCoding = ( index == KByteArrayLineEdit::CharCoding );
     CaseSensitiveCheckBox->setEnabled( isCharCoding );
-    WholeWordsCheckBox->setEnabled( isCharCoding );
+    WholeWordsCheckBox->setEnabled( false );//isCharCoding ); TODO: not implemented!
 }
 
 void KAbstractFindDialog::onSearchDataChanged( const QByteArray &data )
@@ -177,5 +180,3 @@ void KAbstractFindDialog::showEvent( QShowEvent *showEvent )
 KAbstractFindDialog::~KAbstractFindDialog()
 {
 }
-
-#include "kabstractfinddialog.moc"
